@@ -73,24 +73,5 @@ class Post(JSONCodable):
                 print('comment_e', e)
 
                 pass
-    
-    def __get_video(post: Dict) -> (Optional[str], Optional[str]):
-        try:
-            video = post['media']['reddit_video']
-            
-            return video['fallback_url'], video['duration']
-        except:
-            try:
-                video = post['preview']['reddit_video_preview']
-
-                return video['fallback_url'], video['duration']
-            except:
-                return None, None
-
-        
-        post['vid_url'] = post['vid_url'].replace('?source=fallback', '')
-    video_url = post['vid_url']
-    audio_url = video_url.rsplit('/', 1)[0] + '/audio'
-
 
 # ---------------------------------------------------------------------------------------------------------------------------------------- #
\ No newline at end of file
